package require RapptureGUI

set commondir [file join [file dirname [info script]] .. common]
source [file join $commondir geovis_settings.tcl]


set width 400
set height 300
wm geometry . ${width}x${height}
update

Rappture::MapViewer::SetServerList $GEOVIS_SERVERS
set s [Rappture::MapViewer .g [list localhost:2015]]

pack .g -expand yes -fill both

# create xyz layer
set xyzdp [Rappture::GeoMapDataProviderXYZ #auto \
    {http://otile[1234].mqcdn.com/tiles/1.0.0/map/{z}/{x}/{y}.jpg} \
    -cache false]
set l1 [Rappture::GeoMapLayerImage #auto $xyzdp]


# create a colorramp layer
set colormap {
 0.00 0 0 1 1
 0.25 0 1 1 1
 0.50 0 1 0 1
 0.75 1 1 0 1
 1.00 1 0 0 1
}
set crdp [Rappture::GeoMapDataProviderColorramp #auto \
    {file:///usr/share/geovis/landuse/outlandish.tif} \
    -colormap $colormap]
set l2 [Rappture::GeoMapLayerImage #auto $crdp]
$l2 configure -coverage true


# create an OGR Line layer
set ogrdp [Rappture::GeoMapDataProviderOGR #auto \
    line {file:///data/mygeohub/tools/landuse/afr_countries.shp}]
set l3 [Rappture::GeoMapLayer #auto $ogrdp]


# create a map object
set m [Rappture::Map #auto]

# -------------------------------------------------
# launch the mapviewer
# show individual layers of the map at 10 second intervals

# add the OSM layers to the map
set l1name [$m layer add -format blt_tree [$l1 export -format blt_tree]]

# add the colorramp layer to the map
$m layer add -format blt_tree [$l2 export -format blt_tree]

# add the line feature layer to the map
$m layer add -format blt_tree [$l3 export -format blt_tree]

# add the map back to the viewer
$s scale $m
$s add $m

# after 10 seconds, delete the xyz OpenStreetMaps layer
# and update the map viewer widget with the new map.
after 10000 {
    # remove the map from the viewer
    $s remove $m

    # remove the colorramp layer from the map
    $m layer delete $l1name

    # add the map back to the viewer
    $s scale $m
    $s add $m
}

