package require RapptureGUI

# this method is called when a user clicks on a icon in the map
# the method is used at the bottom of this example
# the callback is called with two arguments:
# option - should be one of "annotation", "clear", "feature"
proc handler {option {args ""}} {
    switch $option {
        "annotation" {
            # pass
        }
        "clear" {
            # previously selected features have been unselected.
            # no arguments associated with this option.
        }
        "feature" {
            # a feature was selected, the server returns 4 values about the feature
            # that are held in args:
            # globalObjId - the global object identifier
            # featureIdList - a single value or list of feature identifiers.
            #                 if multiple features are returned, they arei
            #                 enclosed in curly brackets.
            # numFeaturesInLayer - the number of features in the layer
            # layerName - the name of the layer the features were found in.
            #             only features from a single layer can be selected
            #             at a time.
            foreach {globalObjId featureIdList numFeaturesInLayer layerName} $args break
            puts "handler caught\
                globalObjId=\"$globalObjId\"\
                featureIdList=\"$featureIdList\"\
                numFeaturesInLayer=\"$numFeaturesInLayer\"\
                layerName=\"$layerName\""
        }
        default {
            error "bad option \"$option\": should be one of annotation,\
                clean, or feature"
        }
    }
}

set commondir [file join [file dirname [info script]] .. common]
source [file join $commondir geovis_settings.tcl]

set width 400
set height 300
wm geometry . ${width}x${height}
update

Rappture::MapViewer::SetServerList $GEOVIS_SERVERS
set s [Rappture::MapViewer .g [list localhost:2015]]

pack .g -expand yes -fill both

# create an XYZ world layer
set dp1 [Rappture::GeoMapDataProviderXYZ #auto \
    {http://otile[1234].mqcdn.com/tiles/1.0.0/map/{z}/{x}/{y}.jpg}]
set l1 [Rappture::GeoMapLayerImage #auto $dp1 \
        -label  "OSM Map" \
        -description "MapQuest OpenStreetMap Street base layer" \
        -opacity 1.0 ]

# create an feature point layer from a csv file using the OGR driver
# the longitude and latitude fields must be named "longitude" and
# "latitude" respectively
#
# we add the local:// prefix to tell the map viewer widget that
# the file exists locally and needs to be transferred to the
# geovis server.
# set path "local://[file join [file dirname [info script]] coord.csv]"
set path "local://[file join [file dirname [info script]] station_clean.csv]"
set dp2 [Rappture::GeoMapDataProviderOGR #auto icon $path]
set l2 [Rappture::GeoMapLayer #auto $dp2 \
        -label  "CSV data" \
        -description "using OGR data provider to load data from a CSV file" \
        ]

# create a map object
set m [Rappture::Map #auto]

# add all layers to the map object
$m layer add -format blt_tree [$l1 export -format blt_tree]
$m layer add -format blt_tree [$l2 export -format blt_tree]

# add a map to the vis client
$s scale $m
$s add $m


# set the proc/method to be called when a feature is selected on the map.
# in this case we give the full path to the previously defined
# procedure named "handler". for an itcl class method, you may need to
# use itcl::code to get the full path of the  callback method:
# for example: [itcl::code $this handler]
$s setSelectCallback ::handler
